<?php

use Drupal\Core\Site\Settings;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\opigno_module\Entity\OpignoAnswer;
use Drupal\opigno_module\Entity\OpignoActivity;

/**
 * @file
 * Install hooks for opigno_journaling_activity module.
 */

/**
 * Implements hook_removed_post_updates().
 */
function opigno_journaling_activity_removed_post_updates() {
  return [
    'opigno_journaling_activity_post_update_field_collections_migration' => '8.9.x',
    'opigno_journaling_activity_post_update_delete_field_collections' => '8.9.x',
  ];
}

/**
 * Set manual evaluation method on journal activities.
 */
function opigno_journaling_activity_post_update_evaluation_method() {
  $entity_type = 'opigno_activity';
  $field_name = 'opigno_evaluation_method';
  $bundle = 'opigno_journaling_activity';
  if (!FieldConfig::loadByName($entity_type, $bundle, $field_name)) {
    FieldConfig::create([
      'field_name' => $field_name,
      'entity_type' => $entity_type,
      'bundle' => $bundle,
      'settings' => [],
      'label' => 'Evaluation method',
    ])->save();
  }
  // Less than a hundred of these so just do them in one shot.
  $ids = \Drupal::entityTypeManager()->getStorage('opigno_activity')->getQuery()
    ->condition('type', 'opigno_journaling_activity')
    ->accessCheck(FALSE)
    ->execute();
  $activities = OpignoActivity::loadMultiple($ids);
  foreach ($activities as $activity) {
    $activity->opigno_evaluation_method->value = 1;
    $activity->save();
  }
}
