<?php

namespace Drupal\opigno_journaling_activity\Breadcrumb;

use Drupal\aft_opigno\Utility\LearningPath;
use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Link;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\group\Entity\Group;
use Drupal\opigno_group_manager\OpignoGroupContext;

/**
 * Provides a breadcrumb builder base class for Answer View page.
 */
class OpignoJournalingAnswerViewBreadcrumb implements BreadcrumbBuilderInterface {

  /**
   * {@inheritdoc}
   */
  public function applies(RouteMatchInterface $route_match) {
    if ($route_match->getRouteName() == 'entity.opigno_answer.canonical') {
      $answer = $route_match->getParameter('opigno_answer');
      $activity = $answer->getActivity();
      return $activity->getType() == 'opigno_journaling_activity';
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function build(RouteMatchInterface $route_match) {
    $breadcrumb = new Breadcrumb();
    $breadcrumb->addCacheContexts(['route']);
    $breadcrumb->addLink(Link::createFromRoute(t('Home'), '<front>'));

    $answer = $route_match->getParameter('opigno_answer');
    $user_module_status = $answer->user_module_status->entity;
    $learning_path = $user_module_status->learning_path->entity;
    if ($learning_path) {
      $breadcrumb->addCacheableDependency($answer);
      $breadcrumb->addCacheableDependency($learning_path);
      $breadcrumb->addLink(Link::createFromRoute($learning_path->label(), 'entity.group.canonical', ['group' => $learning_path->id()]));
      $breadcrumb->addLink(Link::createFromRoute(t('Journal'), 'view.journal_entries.page_1', ['group' => $learning_path->id()]));
    }

    return $breadcrumb;
  }

}
