<?php

namespace Drupal\opigno_learning_path\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Plugin\Context\Context;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\Core\Plugin\Context\EntityContextDefinition;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Sets the current group as a context on group routes.
 */
class TrainingContext implements ContextProviderInterface {

  use StringTranslationTrait;
  use TrainingContextTrait;

  /**
   * Constructs a new TrainingContext.
   */
  public function __construct(
    protected readonly RouteMatchInterface $currentRouteMatch
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getRuntimeContexts(array $unqualified_context_ids) {
    $result = [];
    foreach ($unqualified_context_ids as $id) {
      if (!\array_key_exists($id, $this->mapping)) {
        continue;
      }
      $entity = $this->getEntityFromRoute($id);
      if ($entity === NULL) {
        continue;
      }

      $context_definition = EntityContextDefinition::fromEntityTypeId($this->mapping[$id])
        ->setRequired(FALSE);
      $cacheability = new CacheableMetadata();
      $cacheability->setCacheContexts(['lms_training:' . $id]);

      $context = new Context($context_definition, $entity);
      $context->addCacheableDependency($cacheability);
      $result[$id] = $context;
    }

    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableContexts() {
    $return = [];
    foreach ($this->mapping as $context_id => $entity_type_id) {
      $return[$context_id] = EntityContext::fromEntityTypeId($context_id, $this->t('Current %parameter from URL', [
        '%parameter' => $context_id,
      ]));
    }
    return $return;
  }

}
