<?php

declare(strict_types=1);

namespace Drupal\opigno_learning_path\Exception;

use Drupal\opigno_learning_path\Entity\LPStatus;
use Drupal\opigno_module\Entity\OpignoModule;

/**
 * Defines a training exceprion class.
 *
 * Error codes:
 *     1 - previous module with minimum score set or mandatory flag
 *         not started,
 *     2 - previous module with mandatory flag not finished,
 *     3 - previous module minimum score not achieved.
 */
final class TrainingException extends \Exception {
  public const REQUIRED_NOT_STARTED = 1;
  public const REQUIRED_NOT_FINISHED = 2;
  public const INSUFFICIENT_SCORE = 3;

  private LPStatus $lpStatus;
  private OpignoModule $module;

  public function __construct(LPStatus $lp_status, OpignoModule $module, int $code) {
    $messages = [
      self::REQUIRED_NOT_STARTED => 'Required module not started',
      self::REQUIRED_NOT_FINISHED => 'Required module not finished',
      self::INSUFFICIENT_SCORE => 'Required score on previous module not met',
    ];

    if (!\array_key_exists($code, $messages)) {
      throw new \InvalidArgumentException('Invalid error code provided.');
    }

    $this->lpStatus = $lp_status;
    $this->module = $module;

    parent::__construct($messages[$code], $code);
  }

  /**
   * Module getter.
   */
  public function getModule(): OpignoModule {
    return $this->module;
  }

  /**
   * LP status getter.
   */
  public function getLpStatus(): LPStatus {
    return $this->lpStatus;
  }

}
