<?php

namespace Drupal\opigno_learning_path;

use Drupal\Core\Entity\EntityFormBuilderInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\group\Entity\GroupRelationship;

/**
 * Class JoinService.
 */
class JoinService {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * The entity form builder.
   *
   * @var \Drupal\Core\Entity\EntityFormBuilderInterface
   */
  protected $entityFormBuilder;

  /**
   * The relation type storage.
   *
   * @var \Drupal\group\Entity\Storage\GroupRelationshipTypeStorage
   */
  protected $relationshipTypeStorage;

  /**
   * Constructs a new JoinService object.
   */
  public function __construct(
    AccountInterface $current_user,
    EntityFormBuilderInterface $entity_form_builder,
    EntityTypeManagerInterface $entityTypeManager
  ) {
    $this->currentUser = $current_user;
    $this->entityFormBuilder = $entity_form_builder;
    $this->relationshipTypeStorage = $entityTypeManager->getStorage('group_content_type');
  }

  /**
   * {@inheritdoc}
   */
  public function getForm($group) {
    // Show a join form, or a request membership form depending on group
    // validation settings.
    $learning_path_id = $group->id();
    $requires_validation = $group->requiresValidation();
    if ($requires_validation) {
      $plugin_id = 'group_membership_request';
      $form_name = 'group-request-membership';
    }
    else {
      $plugin_id = 'group_membership';
      $form_name = 'group-join';
    }

    // Pre-populate group content with the current user.
    $group_content = GroupRelationship::create([
      'type' => $this->relationshipTypeStorage->getRelationshipTypeId('learning_path', $plugin_id),
      'gid' => $group->id(),
      'entity_id' => $this->currentUser->id(),
    ]);
    if ($requires_validation) {
      $group_content->set('grequest_status', 'pending');
    }
    $group_content->learning_path_id = $learning_path_id;

    $form = $this->entityFormBuilder->getForm($group_content, $form_name, ['learning_path_id' => $learning_path_id]);
    return $form;
  }

}
