<?php

namespace Drupal\opigno_learning_path\Plugin\views\field;

use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Link;
use Drupal\group\Entity\GroupInterface;
use Drupal\opigno_learning_path\Entity\LPStatus;
use Drupal\opigno_learning_path\TrainingManager;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Field handler to take training link.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("opigno_learning_path_take_link")
 */
class OpignoLearningPathTakeLink extends FieldPluginBase {

  protected TrainingManager $trainingManager;
  protected AccountProxyInterface $currentUser;

  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    TrainingManager $trainingManager,
    AccountProxyInterface $currentUser
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->trainingManager = $trainingManager;
    $this->currentUser = $currentUser;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('opigno_learning_path.training_manager'),
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // Don't do anything with the query.
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    if ($group = $this->getEntity($values)) {
      if (!$group instanceof GroupInterface && $group->bundle() !== 'learning_path') {
        return;
      }
      $lp_status = $this->trainingManager->getLearningPathStatus($group, $this->currentUser);
      if ($lp_status === NULL) {
        $link_text = $this->t('Get Started');
      }
      elseif ($lp_status->getStatus() === LPStatus::STATUS_NEEDS_EVALUATION) {
        return $this->t('Awaits grading..');
      }
      else {
        $link_text = $this->t('Resume Training');
      }

      // Take the bundle and build the take link.
      return Link::createFromRoute(
        $link_text,
        'opigno_learning_path.steps.start',
        ['group' => $group->id()],
        [
          'attributes' => [
            'class' => ['btn', 'btn-rounded'],
          ],
        ]
      )->toString();
    }
  }

}
