<?php

namespace Drupal\opigno_learning_path\Plugin\views\filter;

use Drupal\Core\Session\AccountProxyInterface;
use Drupal\views\Plugin\views\filter\BooleanOperator;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Filters only for anonymous users.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("opigno_learning_path_anonymous_visibility")
 */

class OpignoAnonymousVisibility extends BooleanOperator {

  private $isAnonymous;

  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    AccountProxyInterface $current_user
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->isAnonymous = $current_user->isAnonymous();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query(): void {
    if (!$this->isAnonymous) {
      return;
    }
    if (!(bool) $this->value && $this->operator === '=') {
      return;
    }
    if ((bool) $this->value && $this->operator === '!=') {
      return;
    }

    parent::query();
  }

}
