<?php

namespace Drupal\opigno_learning_path\TwigExtension;

use Drupal\Core\Render\Markup;
use Drupal\opigno_learning_path\Controller\LearningPathController;
use Drupal\opigno_learning_path\LearningPathAccess;
use Drupal\opigno_learning_path\Traits\LearningPathAchievementTrait;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Class DefaultTwigExtension.
 */
class DefaultTwigExtension extends AbstractExtension {

  use LearningPathAchievementTrait;

  /**
   * {@inheritdoc}
   */
  public function getTokenParsers() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getNodeVisitors() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getTests() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new TwigFunction(
        'is_group_member',
        [$this, 'is_group_member']
      ),
      new TwigFunction(
        'get_start_link',
        [$this, 'get_start_link']
      ),
      new TwigFunction(
        'get_training_content',
        [$this, 'get_training_content']
      ),
      new TwigFunction(
        'opigno_modules_counter',
        [$this, 'opigno_modules_counter']
      ),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getOperators() {
     return [[], []];
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'opigno_learning_path.twig.extension';
  }

  /**
   * Tests if user is member of a group.
   *
   * @param mixed $group
   *   Group.
   * @param mixed $account
   *   User account.
   *
   * @return bool
   *   Member flag.
   */
  public function is_group_member($group = NULL, $account = NULL) {
    if (!$group) {
      $group = \Drupal::routeMatch()->getParameter('group');
    }

    if (empty($group)) {
      return FALSE;
    }

    if (!$account) {
      $account = \Drupal::currentUser();
    }

    return LearningPathAccess::getGroupOrClassMembership($group, $account) !== FALSE;
  }

  /**
   * Returns training content.
   *
   * @return mixed|null
   *   Training content.
   */
  public function get_training_content() {
    $controller = new LearningPathController();
    return $controller->trainingContent();
  }

  /**
   * Counter of modules by group.
   */
  public function opigno_modules_counter($group) {
    $steps = $this->getStepsByGroup($group);
    return Markup::create(count($steps));
  }

}
