<?php

/**
 * @file
 * Contains LMS module post update functions.
 */

/**
 * Update opigno_answer to be revisionable.
 */
function opigno_module_post_update_make_opigno_answer_revisionable(&$sandbox) {
  $definition_update_manager = \Drupal::entityDefinitionUpdateManager();
  /** @var \Drupal\Core\Entity\EntityLastInstalledSchemaRepositoryInterface $last_installed_schema_repository */
  $last_installed_schema_repository = \Drupal::service('entity.last_installed_schema.repository');

  $entity_type = $definition_update_manager->getEntityType('opigno_answer');
  $field_storage_definitions = $last_installed_schema_repository->getLastInstalledFieldStorageDefinitions('opigno_answer');

  // Update the entity type definition.
  $entity_keys = $entity_type->getKeys();
  $entity_keys['revision'] = 'revision_id';
  $entity_keys['revision_translation_affected'] = 'revision_translation_affected';
  $entity_type->set('entity_keys', $entity_keys);
  $entity_type->set('revision_table', 'opigno_answer_revision');
  $entity_type->set('revision_data_table', 'opigno_answer_field_revision');
  $revision_metadata_keys = [
    'revision_default' => 'revision_default',
    'revision_user' => 'revision_user',
    'revision_created' => 'revision_created',
    'revision_log_message' => 'revision_log_message',
  ];
  $entity_type->set('revision_metadata_keys', $revision_metadata_keys);

  // Update the field storage definitions.
  $field_storage_definitions['langcode']->setRevisionable(TRUE);
  $field_storage_definitions['default_langcode']->setRevisionable(TRUE);
  $field_storage_definitions['user_id']->setRevisionable(TRUE);

  \Drupal::entityDefinitionUpdateManager()->updateFieldableEntityType($entity_type, $field_storage_definitions,$sandbox);
}

/**
 * Populate data in lp_status field of user_module_status.
 */
function opigno_module_post_update_status_fields(&$sandbox) {
  $module_status_storage = \Drupal::entityTypeManager()->getStorage('user_module_status');
  $lp_status_storage = \Drupal::entityTypeManager()->getStorage('user_lp_status');
  if (!\array_key_exists('progress', $sandbox)) {
    $sandbox['progress'] = 0;
    $sandbox['list'] = $module_status_storage
      ->getQuery()
      ->accessCheck(FALSE)
      ->execute();
    $sandbox['total'] = \count($sandbox['list']);
  }

  for ($i = 0; $i < 10; $i++) {
    if (\count($sandbox['list']) === 0) {
      $sandbox['#finished'] = 1;
    }
    else {
      $sandbox['progress']++;
      $id = \array_pop($sandbox['list']);
      $module_status = $module_status_storage->load($id);
      if ($module_status !== NULL) {
        $uid_field = $module_status->get('user_id');
        $lp_field = $module_status->get('learning_path');
        $module_field = $module_status->get('module');
        if ($uid_field->isEmpty() || $lp_field->isEmpty() || $module_field->isEmpty()) {
          $module_status->delete();
          \Drupal::logger('opigno_module')->notice('Deleted invalid module status. @progress of @total', [
            '@progress' => $sandbox['progress'],
            '@total' => $sandbox['total'],
          ]);
        }
        $results = $lp_status_storage
          ->getQuery()
          ->accessCheck(FALSE)
          ->condition('uid', $uid_field->target_id)
          ->condition('gid', $lp_field->target_id)
          ->sort('id', 'DESC')
          ->execute();
        if (\count($results) === 0) {
          $module_status->delete();
          \Drupal::logger('opigno_module')->notice('Deleted orphaned module status. @progress of @total', [
            '@progress' => $sandbox['progress'],
            '@total' => $sandbox['total'],
          ]);
        }
        else {
          $lp_status_id = \reset($results);
          $module_status->set('lp_status', $lp_status_id);
          $module_status->save();
          \Drupal::logger('opigno_module')->notice('Updated module status. @progress of @total', [
            '@progress' => $sandbox['progress'],
            '@total' => $sandbox['total'],
          ]);
        }
      }
      $sandbox['#finished'] = $sandbox['progress'] / $sandbox['total'];
    }
  }
}

/**
 * Populate activities data in user_module_status entities.
 */
function opigno_module_post_update_status_activities_field(&$sandbox) {
  $module_status_storage = \Drupal::entityTypeManager()->getStorage('user_module_status');
  if (!\array_key_exists('progress', $sandbox)) {
    $sandbox['progress'] = 0;
    $sandbox['list'] = $module_status_storage
      ->getQuery()
      ->accessCheck(FALSE)
      ->execute();
    $sandbox['total'] = \count($sandbox['list']);
  }

  $training_manager = \Drupal::service('opigno_learning_path.training_manager');
  for ($i = 0; $i < 10; $i++) {
    if (\count($sandbox['list']) === 0) {
      $sandbox['#finished'] = 1;
    }
    else {
      $sandbox['progress']++;
      $id = \array_pop($sandbox['list']);
      $module_status = $module_status_storage->load($id);
      if ($module_status !== NULL) {
        $current_activity_id = NULL;
        $current_activity_field = $module_status->get('current_activity');
        if (!$current_activity_field->isEmpty()) {
          $current_activity_id = $current_activity_field->target_id;
        }
        try {
          $training_manager->setModuleStatusActivities($module_status, $current_activity_id);
          $module_status->save();
        }
        catch (\Exception $e) {
          watchdog_exception('opigno_module', $e);
        }
      }
      $sandbox['#finished'] = $sandbox['progress'] / $sandbox['total'];
    }
  }
  return t('@count module status entities remaining to update', ['@count' => count($sandbox['list'])]);
}
