<?php

namespace Drupal\opigno_module\Form;

use Drupal\Core\Entity\ContentEntityDeleteForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for deleting Activity entities.
 *
 * @ingroup opigno_module
 */
class OpignoActivityDeleteForm extends ContentEntityDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    \Drupal::service('opigno_learning_path.progress_checker')->checkActivityhasProgress($this->entity->id(), TRUE);

    // Check if this activity has unevaluated answers.
    $query = $this->entityTypeManager->getStorage('opigno_answer')->getQuery();
    $unevaluated_answer_count = $query
      ->accessCheck(FALSE)
      ->condition('activity', $this->entity->id())
      ->condition('evaluated', FALSE)
      ->count()
      ->execute();
    if ($unevaluated_answer_count !== 0) {
      $this->messenger()->addWarning($this->t('Warning! This activity has @count unevaluated answers.', [
        '@count' => $unevaluated_answer_count,
      ]));
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $storage = $form_state->getStorage();
    if (isset($storage['activity_answers'])) {
      // Activity has answers.
      $form_state->setRedirectUrl($this->getRedirectUrl());
      $this->messenger()->addMessage($storage['activity_message'], 'warning');
    }
    else {
      // Normal activity deleting.
      parent::submitForm($form, $form_state);
    }
  }

}
