<?php

namespace Drupal\opigno_padlet\Plugin\ActivityAnswer;

use Drupal\Core\Url;
use Drupal\opigno_module\ActivityAnswerPluginBase;
use Drupal\opigno_module\Entity\OpignoActivityInterface;
use Drupal\opigno_module\Entity\OpignoAnswerInterface;

/**
 * @ActivityAnswer(
 *   id="opigno_padlet",
 * )
 */
class PadletActivityAnswer extends ActivityAnswerPluginBase {

  /**
   * {@inheritdoc}
   */
  public function evaluatedOnSave(OpignoActivityInterface $activity) {
    // Answer must be evaluated manually.
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getScore(OpignoAnswerInterface $answer) {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function getAnswerResultItemHeaders(OpignoAnswerInterface $answer) {
    $headings = [
      $this->t('Padlet'),
    ];

    if (!$answer->isEvaluated()) {
      $headings[] = $this->t('Result');
    }

    return $headings;
  }

  /**
   * {@inheritdoc}
   */
  public function getAnswerResultItemData(OpignoAnswerInterface $answer) {
    $data = [];

    $padlet_url = $answer->getActivity()->get('field_padlet_url')->uri;
    $data['item'][] = [
      'data' => [
        '#type' => 'link',
        '#title' => $padlet_url,
        '#url' => Url::fromUri($padlet_url),
        '#attributes' => [
          'target' => '_blank',
        ],
      ],
    ];

    if (!$answer->isEvaluated()) {
      $data['item'][] = $this->t('This answer has not yet been scored.');
    }

    return $data;
  }

}
