<?php

namespace Drupal\opigno_pass_fail\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\opigno_learning_path\TrainingManager;
use Drupal\opigno_pass_fail\Service\OpignoPassFailScoreManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

class OpignoPassFailScoreForm extends FormBase {

  /**
   * The score manager.
   */
  protected OpignoPassFailScoreManager $scoreManager;

  /**
   * The training manager.
   */
  protected TrainingManager $trainingManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    OpignoPassFailScoreManager $scoreManager,
    TrainingManager $trainingManager
  ) {
    $this->scoreManager = $scoreManager;
    $this->trainingManager = $trainingManager;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('opigno_pass_fail.score_manager'),
      $container->get('opigno_learning_path.training_manager'),

    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    // Yes, not consistent.
    // @todo Change this here and in CSS.
    return 'opigno_journaling_score_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\opigno_module\Entity\OpignoAnswer $answer */
    $answer = $form_state->getBuildInfo()['args'][0];
    $score = $answer->isEvaluated() ? $answer->getScore() : FALSE;

    $statuses = $this->scoreManager->getStatusesMap();

    $form['actions']['pass'] = [
      '#type' => 'submit',
      '#value' => $this->t('Pass'),
      '#name' => 'pass',
      '#attributes' => [
        'disabled' => $score === $statuses['pass'],
        'class' => [$score === $statuses['pass'] ? 'btn-info' : ''],
      ],
    ];

    $form['actions']['incomplete'] = [
      '#type' => 'submit',
      '#value' => $this->t('Incomplete'),
      '#name' => 'incomplete',
      '#attributes' => [
        'disabled' => $score === $statuses['incomplete'],
        'class' => [$score === $statuses['incomplete'] ? 'btn-info' : ''],
      ],
    ];

    $form['actions']['resubmit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Resubmit'),
      '#name' => 'resubmit',
      '#attributes' => [
        'disabled' => $score === $statuses['resubmit'],
        'class' => [$score === $statuses['resubmit'] ? 'btn-info' : ''],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement()['#name'];
    /** @var \Drupal\opigno_module\Entity\OpignoAnswer $answer */
    $answer = $form_state->getBuildInfo()['args'][0];

    // If score is valid, set it as answer score and mark the answer evaluated.
    if ($score = $this->scoreManager->getScoreFromStatus($triggering_element)) {
      $answer
        ->setEvaluated(TRUE)
        ->setScore($score)
        ->save();

      $module_status = $answer->getUserModuleStatus();
      $this->trainingManager->updateModuleStatus($module_status);

      $lp_status = $module_status->get('lp_status')->entity;
      $this->trainingManager->updateLpStatus($lp_status);
    }
  }

}
