<?php

namespace Drupal\opigno_pass_fail\Service;

use Drupal\Core\StringTranslation\StringTranslationTrait;

class OpignoPassFailScoreManager {
  use StringTranslationTrait;

  /**
   * Journal answer scores.
   *
   * @var array
   */
  protected $scores;

  /**
   * Journal answer statuses.
   *
   * @var array
   */
  protected $statuses;

  /**
   * Journal answer status labels.
   *
   * @var array
   */
  protected $labels;

  /**
   * Map of status keyed by scores.
   *
   * @var array
   */
  protected $map;

  /**
   * Map of labels keyed by statuses.
   *
   * @var array
   */
  protected $labelMap;

  /**
   * OpignoPassFailScoreManager constructor.
   */
  public function __construct() {
    // @todo: EL-635: the default maximum score for an activity is 10, but this
    // is configurable per-activity, per module. Consider dynamically responding
    // to the maximum score instead of hardcoding these values.
    $this->scores = [1, 5, 10];
    $this->statuses = ['resubmit', 'incomplete', 'pass'];
    $this->labels = [$this->t('Resubmit'), $this->t('Incomplete'), $this->t('Pass')];
    $this->map = array_combine($this->scores, $this->statuses);
    $this->labelMap = array_combine($this->statuses, $this->labels);
  }

  /**
   * Get the status from score.
   *
   * @param $score
   *   The score.
   *
   * @return bool
   */
  public function getStatusFromScore($score) {
    $map = $this->getScoresMap();
    return isset($map[$score]) ? $map[$score] : FALSE;
  }

  /**
   * Get the score from status.
   *
   * @param $status
   *   The status.
   *
   * @return bool|int
   */
  public function getScoreFromStatus($status) {
    $map = $this->getStatusesMap();
    return isset($map[$status]) ? (int) $map[$status] : FALSE;
  }

  /**
   * Get the scores map.
   *
   * @return array|false
   */
  public function getScoresMap() {
    return $this->map;
  }

  /**
   * Get the statuses map.
   *
   * @return array|null
   */
  public function getStatusesMap() {
    $map = $this->getScoresMap();
    return array_flip($map);
  }

  /**
   * Get the status label.
   *
   * @param $status
   *   The staus.
   *
   * @return bool
   */
  public function getStatusLabel($status) {
    return isset($this->labelMap[$status]) ? $this->labelMap[$status] : FALSE;
  }
}
