<?php

namespace Drupal\opigno_team_activity;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\group\Entity\GroupInterface;
use Drupal\opigno_module\Entity\OpignoActivityInterface;

/**
 * AssignmentGroups service.
 */
class AssignmentGroups {

  /**
   * The group storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $groupStorage;

  /**
   * Constructs an AssignmentGroups object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->groupStorage = $entity_type_manager->getStorage('group');
  }

  /**
   * Get activity groups.
   *
   * @param \Drupal\group\Entity\GroupInterface $group
   *   The related group.
   * @param \Drupal\opigno_module\Entity\OpignoActivityInterface $activity
   *   The group activity.
   *
   * @return \Drupal\group\Entity\GroupInterface[]
   *   A list of group activity groups.
   */
  public function getActivityGroups(GroupInterface $group, OpignoActivityInterface $activity): array {
    $query = $this->groupStorage->getQuery()
      ->accessCheck(FALSE)
      ->condition('team_activity', $activity->id())
      ->condition('membership_group', $group->id())
      ->condition('type', 'team_activity');
    return $this->groupStorage->loadMultiple($query->execute());
  }

  /**
   * Get a user's activity groups.
   *
   * Filter for only learning paths or classes the user is a member.
   *
   * @param \Drupal\group\Entity\GroupInterface $group
   *   The related group.
   * @param \Drupal\opigno_module\Entity\OpignoActivityInterface $activity
   *   The group activity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account.
   *
   * @return \Drupal\group\Entity\GroupInterface[]
   *   A list of a user's group activity groups.
   */
  public function getUserActivityGroups(GroupInterface $group, OpignoActivityInterface $activity, AccountInterface $account): array {
    return array_filter($this->getActivityGroups($group, $activity), static function(GroupInterface $group) use ($account) {
      return $group->getMember($account);
    });
  }

}
