<?php

namespace Drupal\opigno_team_activity\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\opigno_team_activity\Form\GroupActivityTeamGroupManagementForm;
use Drupal\opigno_module\Entity\OpignoActivityInterface;
use Drupal\opigno_module\Entity\OpignoModuleInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for LMS group activity routes.
 */
class GroupActivityTeamGroupManagement extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The assignment group service.
   *
   * @var \Drupal\opigno_team_activity\AssignmentGroups
   */
  protected $assignmentGroups;

  /**
   * The controller constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * Title callback for controller.
   *
   * @param \Drupal\opigno_module\Entity\OpignoActivityInterface $opigno_activity
   *   The opigino activity.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The page title.
   */
  public function title(OpignoActivityInterface $opigno_activity) {
    return $this->t('Teams for @assignment', ['@assignment' => $opigno_activity->label()]);
  }

  /**
   * Builds the response.
   */
  public function build(OpignoModuleInterface $opigno_module, OpignoActivityInterface $opigno_activity) {
    $group_storage = $this->entityTypeManager->getStorage('group');
    $group_ids = $group_storage->getQuery()
      ->accessCheck(TRUE)
      ->condition('team_activity', $opigno_activity->id())
      ->execute();
    if ($group_ids) {
      /** @var \Drupal\group\Entity\GroupInterface $group */
      foreach ($group_storage->loadMultiple($group_ids) as $group) {
        $build[$group->get('membership_group')->target_id]['#type'] = 'details';
        $build[$group->get('membership_group')->target_id]['#title'] = $this->t('Activities for %group', ['%group' => $group->get('membership_group')->entity->label()]);
        $build[$group->get('membership_group')->target_id]['#open'] = 'details';
        $group_form = \Drupal::service('entity.form_builder')->getForm($group, 'edit');
        $group_form['team_activity']['widget'][0]['target_id']['#attributes']['readonly'] = TRUE;
        $group_form['file_upload']['#access'] = FALSE;
        $build[$group->get('membership_group')->target_id][$group->id()] = $group_form;
      }
    }
    $build['generate'] = \Drupal::formBuilder()->getForm(GroupActivityTeamGroupManagementForm::class, $opigno_module, $opigno_activity);
    return $build;
  }

}
