<?php

namespace Drupal\opigno_team_activity\Plugin\ActivityAnswer;

use Drupal\opigno_module\ActivityAnswerPluginBase;
use Drupal\opigno_module\Entity\OpignoActivityInterface;
use Drupal\opigno_module\Entity\OpignoAnswerInterface;

/**
 * Class GroupActivityAnswer.
 *
 * @ActivityAnswer(
 *   id="opigno_team_activity",
 * )
 */
class GroupActivityAnswer extends ActivityAnswerPluginBase {

  /**
   * {@inheritdoc}
   */
  public function evaluatedOnSave(OpignoActivityInterface $activity) {
    // Manual evaluation.
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getScore(OpignoAnswerInterface $answer) {
    // Set default max score.
    $score = 10;
    $activity = $answer->getActivity();

    // Get max score for activity.
    $db_connection = \Drupal::service('database');
    $score_query = $db_connection->select('opigno_module_relationship', 'omr')
      ->fields('omr', ['max_score'])
      ->condition('omr.parent_id', $answer->getModule()->id())
      ->condition('omr.parent_vid', $answer->getModule()->getRevisionId())
      ->condition('omr.child_id', $activity->id())
      ->condition('omr.child_vid', $activity->getRevisionId());
    $score_result = $score_query->execute()->fetchField();

    if ($score_result) {
      $score = $score_result;
    }

    return $score;
  }

  /**
   * {@inheritdoc}
   */
  public function getAnswerResultItemHeaders(OpignoAnswerInterface $answer) {
    $headings = [$this->t('Your group\'s response')];
    if (!$answer->isEvaluated()) {
      $headings[] = $this->t('Result');
    }
    return $headings;
  }

  /**
   * Returns answer result data.
   */
  public function getAnswerResultItemData(OpignoAnswerInterface $answer) {
    $data = [];
    /** @var \Drupal\opigno_module\Entity\OpignoActivityInterface $activity */
    $activity = $answer->getActivity();

    $account = \Drupal::currentUser();
    $group_storage = \Drupal::entityTypeManager()->getStorage('group');
    $group_ids = $group_storage->getQuery()
      ->accessCheck(FALSE)
      ->condition('team_activity', $activity->id())
      ->execute();
    if ($group_ids) {
      /** @var \Drupal\group\Entity\GroupInterface $group */
      foreach ($group_storage->loadMultiple($group_ids) as $group) {
        if ($group->getMember($account)) {
          /** @var \Drupal\file\Entity\File $uploaded_file */
          $uploaded_file = $group->get('file_upload')->entity;
          if ($uploaded_file !== NULL) {
            $file_link = [
              '#theme' => 'file_link',
              '#file' => $uploaded_file,
            ];
            $data['item'][] = \Drupal::service('renderer')->render($file_link);
          }
          continue;
        }
      }
    }

    if (empty($data)) {
      $data['item'][] = $this->t('This answer did not have response.');
    }

    return $data;
  }

}
