<?php

namespace Drupal\opigno_webform\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\webform\WebformInterface;
use Drupal\webform_ui\Access\WebformUiAccess;

/**
 * Defines the custom access control handler for LMS Activity webforms.
 */
class OpignoWebformAccess {

  /**
   * Check that webform source can be updated by a user.
   *
   * @param \Drupal\webform\WebformInterface $webform
   *   A webform.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public static function checkWebformActivityAccess(WebformInterface $webform, $type, AccountInterface $account) {
    if ($webform->get('category') === 'Activity') {
      return AccessResult::forbidden()->addCacheableDependency($webform);
    }

    // Fall back to the original access check.
    return WebformUiAccess::checkWebformElementAccess($webform, $type, $account);
  }

}
