<?php

namespace Drupal\opigno_webform\Plugin\ActivityAnswer;

use Drupal\Component\Render\PlainTextOutput;
use Drupal\Core\Database\Connection;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\opigno_module\ActivityAnswerPluginBase;
use Drupal\opigno_module\Entity\OpignoActivityInterface;
use Drupal\opigno_module\Entity\OpignoAnswerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @ActivityAnswer(
 *   id="opigno_webform",
 * )
 */
class WebformActivityAnswer extends ActivityAnswerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * The constructor.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected readonly Connection $db
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition,
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function evaluatedOnSave(OpignoActivityInterface $activity) {
    $method = $activity->get('opigno_evaluation_method')->value;
    if ($method == 0) {
      return TRUE;
    }
    else {
      return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getScore(OpignoAnswerInterface $answer) {
    if (!$this->evaluatedOnSave($answer->getActivity())) {
      return 0;
    }

    $activity = $answer->getActivity();
    $score_query = $this->db->select('opigno_module_relationship', 'omr')
      ->fields('omr', ['max_score'])
      ->condition('omr.parent_id', $answer->getModule()->id())
      ->condition('omr.parent_vid', $answer->getModule()->getRevisionId())
      ->condition('omr.child_id', $activity->id())
      ->condition('omr.child_vid', $activity->getRevisionId());
    $score_result = $score_query->execute()->fetchField();

    return $score_result ? (int) $score_result : 0;
  }

  /**
   * {@inheritdoc}
   */
  public function getAnswerResultItemHeaders(OpignoAnswerInterface $answer) {
    $headings = [$this->t('Your answer')];
    if (!$answer->isEvaluated()) {
      $headings[] = $this->t('Result');
    }
    return $headings;
  }

  /**
   * {@inheritdoc}
   */
  public function getAnswerResultItemData(OpignoAnswerInterface $answer) {
    if ($webform_submission = $answer->get('field_webform_answer')->entity) {
      $view_builder = \Drupal::entityTypeManager()->getViewBuilder('webform_submission');
      $data['item'][] = PlainTextOutput::renderFromHtml($view_builder->view($webform_submission));
    }

    if (!$answer->isEvaluated()) {
      $data['item'][] = $this->t('This answer has not yet been scored.');
    }

    return $data;
  }

}
